#!/bin/bash

function log()
{
	echo $@ >> ~/install.log.hinemos_web
}

function log_n()
{
	echo -n $@ >> ~/install.log.hinemos_web
}

function log_un()
{
	echo $@ >> ~/uninstall.log.hinemos_web
}

function echo_ok()
{
	log " [OK]"
}

function echo_ng()
{
	log " [NG]"
}

function echo_msg()
{
	local PARAM=$1
	
	if [ -e ${HINEMOS_WEB_HOME}/lib/${LANGUAGE}_install.lng ]
	then
		. ${HINEMOS_WEB_HOME}/lib/${LANGUAGE}_install.lng
	fi
	
	eval 'log "${'${PARAM}'}"'
}

function echo_msg_n(){
	local PARAM=$1
	if [ -e ${HINEMOS_WEB_HOME}/lib/${LANGUAGE}_install.lng ]
	then
		. ${HINEMOS_WEB_HOME}/lib/${LANGUAGE}_install.lng
	fi

	eval 'log_n "${'${PARAM}'}"'
}

function configure_files()
{
	log 
	echo_msg_n MSG_I001
	if [ "$LANGUAGE" = "jp" ]
	then
		locale="ja_JP.UTF-8"
	else
		locale="en_US.UTF-8"
	fi
	
	# create conf folder
	cp -pr ${HINEMOS_WEB_HOME}/conf.template ${HINEMOS_WEB_HOME}/conf
	
	# configure hinemos.cfg
	sed -i -e "s|%%HINEMOS_WEB_HOME%%|${HINEMOS_WEB_HOME}|" \
		-e "s|%%HINEMOS_WEB_ETC_DIR%%|${HINEMOS_WEB_ETC_DIR}|" \
		-e "s|%%HINEMOS_WEB_LOG_DIR%%|${HINEMOS_WEB_LOG_DIR}|" \
		-e "s|%%JAVA_HOME%%|${JAVA_HOME}|" \
		-e "s|%%JAVA_SDK_HOME%%|${JAVA_SDK_HOME}|" \
		-e "s|%%TOMCAT_HOME%%|${TOMCAT_HOME}|" \
		-e "s|%%HINEMOS_OS_USER%%|${HINEMOS_OS_USER}|" \
		-e "s|%%LOCALE%%|${locale}|" \
		${HINEMOS_WEB_ETC_DIR}/hinemos_web.cfg
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E001
		return 255
	fi

	# configure server.xml
	sed -i -e "s|%%HINEMOS_WEB_LOG_DIR%%|${HINEMOS_WEB_LOG_DIR}|" \
	   ${HINEMOS_WEB_ETC_DIR}/server.xml
	
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E001
		return 255
	fi
	
	# configure log4j.properties(tomcat)
	sed -i -e "s|%%HINEMOS_WEB_LOG_DIR%%|${HINEMOS_WEB_LOG_DIR}|" \
		${HINEMOS_WEB_ETC_DIR}/log4j.properties
	
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E001
		return 255
	fi
	
	# configure config.ini(tomcat)
	cp $HINEMOS_WEB_HOME/sbin/conf/config.ini ${HINEMOS_WEB_HOME}/webapps/ROOT/WEB-INF/configuration/
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E001
		return 255
	fi
	
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E001
		return 255
	fi

	echo_ok
	
	return 0
}

function configure_hinemos_web_service()
{
	#hinemos webclient
	chkconfig --add hinemos_web
}

function remove_hinemos_web_service()
{
	/etc/init.d/hinemos_web stop
	chkconfig --del hinemos_web
}

function extract_war_file()
{
	unzip -o -d ${HINEMOS_WEB_HOME}/webapps/ROOT/ ${HINEMOS_WEB_HOME}/webapps/ROOT.war >> ~/install.log.hinemos_web 2>&1
}

function extract_tomcat_file()
{
	rm -Rf ${TOMCAT_HOME} >> ~/install.log.hinemos_web 2>&1
	tar -xzf ${HINEMOS_WEB_HOME}/thirdparty/${TOMCAT_PACKAGE} >> ~/install.log.hinemos_web 2>&1
	mv ${TOMCAT_EXTRACT_DIR} ${TOMCAT_HOME} >> ~/install.log.hinemos_web 2>&1
	ln -s ${HINEMOS_WEB_ETC_DIR}/log4j.properties ${TOMCAT_HOME}/lib/log4j.properties >> ~/install.log.hinemos_web 2>&1
	ln -s ${HINEMOS_WEB_ETC_DIR}/server.xml ${TOMCAT_HOME}/conf/server.xml >> ~/install.log.hinemos_web 2>&1
	mkdir -p ${HINEMOS_WEB_HOME}/var/rap
}